@@ -52,6 +52,8 @@ def sph2cart(alpha, beta, r):
     z : float or `numpy.ndarray`
         z-component of Cartesian coordinates
     """
+    r = np.where(r != 0, r, 1) # compensate missing radius entries in various databases
+
     x = r * np.cos(alpha) * np.sin(beta)
     y = r * np.sin(alpha) * np.sin(beta)
     z = r * np.cos(beta)
@@ -83,13 +85,13 @@ def cart2sph(x, y, z):
     """
     r = np.sqrt(x**2 + y**2 + z**2)
     alpha = np.arctan2(y, x)
-    beta = np.arccos(z / r)
+    beta = np.arccos(z / np.where(r != 0, r, 1))
     return alpha, beta, r
 
 def transform(u, rot, x0, invert):
     if not invert: u-=x0
     t = rot.apply(u, inverse=invert)
-    if invert: t+=x0
+    if invert: t = t + x0
     return t
 
 class Coordinates(access.ArrayVariable):
@@ -128,13 +130,14 @@ class Coordinates(access.ArrayVariable):
             if old_units == None: raise Exception("missing original unit for unit conversion")
 
             conversion = np.ones_like(coords)
+            indices = access.get_slice_tuple(dimensions, {"C":slice(2)})
             
             if (old_units in Coordinates.System.Units.Degree and new_units in Coordinates.System.Units.Degree) or (old_units in Coordinates.System.Units.Radians and new_units in Coordinates.System.Units.Radians):
                 return coords
             elif old_units in Coordinates.System.Units.Degree and new_units in Coordinates.System.Units.Radians: 
-                conversion[access.get_slice_tuple(dimensions, {"C":slice(2)})] = np.pi/180
+                conversion[indices] = np.pi/180
             elif old_units in Coordinates.System.Units.Radians and new_units in Coordinates.System.Units.Degree: 
-                conversion[access.get_slice_tuple(dimensions, {"C":slice(2)})] = 180/np.pi
+                conversion[indices] = 180/np.pi
             else: raise Exception("invalid angle unit in conversion from {0} to {1}".format(old_units, new_units))
 
             return np.multiply(coords, conversion)
@@ -304,7 +307,7 @@ class Coordinates(access.ArrayVariable):
 
         # get rotation of ref_object
         order = ("M","C")
-        r_pos, r_view, r_up = ref_object.get_pose(indices, order, Coordinates.System.Cartesian, angle_unit)
+        r_pos, r_view, r_up = ref_object.get_pose(indices, order, Coordinates.System.Cartesian, "rad")
         if len(r_view)!=len(r_up):
             vlen = len(r_view)
             ulen = len(r_up)
@@ -320,7 +323,8 @@ class Coordinates(access.ArrayVariable):
         transformed_values = None
 
         if ldim != None:
-            transformed_values = np.empty(untransformed_values.shape)
+            shape = tuple(np.max(np.asarray([np.asarray(untransformed_values.shape)[1:], np.asarray(r_pos.shape), np.asarray(r_view.shape), np.asarray(r_up.shape)]), axis=0))
+            transformed_values = np.empty((untransformed_values.shape[0],)+shape)
             for c in np.arange(untransformed_values.shape[0]): transformed_values[c] = transform(untransformed_values[c], rotations, r_pos, invert)
         else: transformed_values = transform(untransformed_values, rotations, r_pos, invert)
 
